# HG changeset patch
# User Simon Guest <simon.guest@agresearch.co.nz>
# Date 1381450572 -46800
#      Fri Oct 11 13:16:12 2013 +1300
# Node ID a191d9f60fa5e6461ab2caa09dfd7a97c343c25e
# Parent  efe46df9f7cb98de9228ee3c2f1ac07a18edfab2
Facility to disable tool dependency package installation from toolshed.

diff -r efe46df9f7cb -r a191d9f60fa5 lib/galaxy/config.py
--- a/lib/galaxy/config.py	Fri Oct 04 22:51:25 2013 -0500
+++ b/lib/galaxy/config.py	Fri Oct 11 13:16:12 2013 +1300
@@ -50,6 +50,7 @@
         self.openid_config = kwargs.get( 'openid_config_file', 'openid_conf.xml' )
         self.enable_quotas = string_as_bool( kwargs.get( 'enable_quotas', False ) )
         self.tool_sheds_config = kwargs.get( 'tool_sheds_config_file', 'tool_sheds_conf.xml' )
+        self.enable_tool_shed_package_dependency_installation = string_as_bool( kwargs.get( 'enable_tool_shed_package_dependency_installation', True ) )
         self.enable_unique_workflow_defaults = string_as_bool( kwargs.get( 'enable_unique_workflow_defaults', False ) )
         self.tool_path = resolve_path( kwargs.get( "tool_path", "tools" ), self.root )
         self.tool_data_path = resolve_path( kwargs.get( "tool_data_path", "tool-data" ), os.getcwd() )
diff -r efe46df9f7cb -r a191d9f60fa5 lib/tool_shed/util/common_install_util.py
--- a/lib/tool_shed/util/common_install_util.py	Fri Oct 04 22:51:25 2013 -0500
+++ b/lib/tool_shed/util/common_install_util.py	Fri Oct 11 13:16:12 2013 +1300
@@ -6,6 +6,7 @@
 from galaxy import util
 from galaxy import web
 from galaxy.util import json
+from galaxy.tools.deps.resolvers import INDETERMINATE_DEPENDENCY
 import tool_shed.util.shed_util_common as suc
 from tool_shed.util import common_util
 from tool_shed.util import container_util
@@ -448,7 +449,18 @@
                         break
                 if tool_dependency.can_install:
                     try:
-                        tool_dependency = install_package( app, elem, tool_shed_repository, tool_dependencies=tool_dependencies )
+                        # default is that tool shed package dependency installation is enabled
+                        if app.config.enable_tool_shed_package_dependency_installation:
+                            tool_dependency = install_package( app, elem, tool_shed_repository, tool_dependencies=tool_dependencies )
+                        else:
+                            # Configured not to install package dependencies from toolshed,
+                            # so they ought to be available via the dependency manager.
+                            # We check this is the case.
+                            if app.toolbox.dependency_manager and app.toolbox.dependency_manager.find_dep( package_name, package_version, type='package' ) != INDETERMINATE_DEPENDENCY:
+                                tool_dependency.status = app.model.ToolDependency.installation_status.INSTALLED
+                            else:
+                                tool_dependency.status = app.model.ToolDependency.installation_status.ERROR
+                                log.warning( "tool dependency %s version %s not available via dependency manager", str(package_name), str(package_version) )
                     except Exception, e:
                         error_message = "Error installing tool dependency %s version %s: %s" % ( str( package_name ), str( package_version ), str( e ) )
                         log.exception( error_message )
diff -r efe46df9f7cb -r a191d9f60fa5 universe_wsgi.ini.sample
--- a/universe_wsgi.ini.sample	Fri Oct 04 22:51:25 2013 -0500
+++ b/universe_wsgi.ini.sample	Fri Oct 11 13:16:12 2013 +1300
@@ -655,6 +655,14 @@
 # Details" option in the history.  Administrators can always see this.
 #expose_dataset_path = False
 
+# This option may be used to disable installation of package
+# dependencies from tool sheds, which usually means downloading a
+# source tarball and compiling it locally.  You would disable this if
+# you want to make use of system installed packages for example.  In
+# that case, alternative tool dependency resolvers should be
+# configured in dependency_resolvers_conf.xml
+#enable_tool_shed_package_dependency_installation = True
+
 # Data manager configuration options
 # Allow non-admin users to view available Data Manager options
 #enable_data_manager_user_view = False
